@@ -5,15 +5,18 @@
 package smux
 
 import (
+	"errors"
 	"fmt"
 	"io"
+	"math"
 	"time"
-
-	"github.com/pkg/errors"
 )
 
 // Config is used to tune the Smux session
 type Config struct {
+	// SMUX Protocol version, support 1,2
+	Version int
+
 	// KeepAliveInterval is how often to send a NOP command to the remote
 	KeepAliveInterval time.Duration
 
@@ -28,20 +31,29 @@ type Config struct {
 	// MaxReceiveBuffer is used to control the maximum
 	// number of data in the buffer pool
 	MaxReceiveBuffer int
+
+	// MaxStreamBuffer is used to control the maximum
+	// number of data per stream
+	MaxStreamBuffer int
 }
 
 // DefaultConfig is used to return a default configuration
 func DefaultConfig() *Config {
 	return &Config{
+		Version:           1,
 		KeepAliveInterval: 10 * time.Second,
 		KeepAliveTimeout:  30 * time.Second,
 		MaxFrameSize:      32768,
 		MaxReceiveBuffer:  4194304,
+		MaxStreamBuffer:   65536,
 	}
 }
 
 // VerifyConfig is used to verify the sanity of configuration
 func VerifyConfig(config *Config) error {
+	if !(config.Version == 1 || config.Version == 2) {
+		return errors.New("unsupported protocol version")
+	}
 	if config.KeepAliveInterval == 0 {
 		return errors.New("keep-alive interval must be positive")
 	}
@@ -57,6 +69,15 @@ func VerifyConfig(config *Config) error {
 	if config.MaxReceiveBuffer <= 0 {
 		return errors.New("max receive buffer must be positive")
 	}
+	if config.MaxStreamBuffer <= 0 {
+		return errors.New("max stream buffer must be positive")
+	}
+	if config.MaxStreamBuffer > config.MaxReceiveBuffer {
+		return errors.New("max stream buffer must not be larger than max receive buffer")
+	}
+	if config.MaxStreamBuffer > math.MaxInt32 {
+		return errors.New("max stream buffer cannot be larger than 2147483647")
+	}
 	return nil
 }
 
